﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using ThinkGeo.MapSuite.WebEdition;
using ThinkGeo.MapSuite.Core;
using System.Configuration;

namespace WebApplication1
{
    public partial class _Default : System.Web.UI.Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            if (!Page.IsPostBack)
            {
                this.ConfigureMap();
            }
        }

        /// <summary>
        /// Configures the map.
        /// </summary>
        private void ConfigureMap()
        {

            // TODO: Read the settings from an XML file or from the DB
            this.Map1.MapBackground.BackgroundBrush = new GeoSolidBrush(GeoColor.GeographicColors.ShallowOcean);

            this.Map1.MapTools.MouseCoordinate.Enabled = true;
            this.Map1.MapTools.MouseCoordinate.MouseCoordinateType = MouseCoordinateType.LatitudeLongitude;
            OverlaySwitcherMapTool overLaySwitcher = new OverlaySwitcherMapTool();

            if (ConfigurationManager.AppSettings["GoogleMapOverlay"].ToString().ToLower() == "true")
            {
                this.Map1.MapUnit = GeographyUnit.Meter;
                this.CreateBaseStaticLayerFromGoogle();

                Proj4Projection baseMapProjection = new Proj4Projection();
                baseMapProjection.InternalProjectionParametersString = Proj4Projection.GetEpsgParametersString(4326);
                baseMapProjection.ExternalProjectionParametersString = Proj4Projection.GetGoogleMapParametersString();

                this.Map1.MapTools.MiniMap.Enabled = false;
                this.Map1.MapTools.ScaleLine.Enabled = false;
                this.Map1.MapTools.OverlaySwitcher.Enabled = false;
            }
            else
            {
                this.Map1.MapUnit = GeographyUnit.DecimalDegree;
                this.Map1.MapTools.MiniMap.Enabled = true;
                this.Map1.MapTools.ScaleLine.Enabled = true;

                overLaySwitcher.Enabled = true;
                this.Map1.MapTools.OverlaySwitcher.Enabled = true;
            }

            this.AddContextMenus();
        }

        /// <summary>
        /// Adds the context menus to the map.
        /// </summary>
        private void AddContextMenus()
        {
            #region temp removed
            //ContextMenu menuOnMap = new ContextMenu("area", 180);
            //// TODO: Only execute for GoogleMaps

            //ContextMenuItem contextMenuView = new ContextMenuItem(string.Format("<DIV>{0}</DIV>", GetLocalResourceObject("contextMenuViewText.Text")));
            //ContextMenuItem contextMenuViewNormal = new ContextMenuItem(string.Format("<DIV onclick=JavaScript:gMapNormal();>{0}</DIV>", GetLocalResourceObject("contextMenuViewNormalText.Text")));
            //ContextMenuItem contextMenuViewPhysical = new ContextMenuItem(string.Format("<DIV onclick=JavaScript:gMapPhysical();>{0}</DIV>", GetLocalResourceObject("contextMenuViewPhysicalText.Text")));
            //ContextMenuItem contextMenuViewSatellite = new ContextMenuItem(string.Format("<DIV onclick=JavaScript:gMapSatellite();>{0}</DIV>", GetLocalResourceObject("contextViewMenuSatelliteText.Text")));
            //ContextMenuItem contextMenuViewHybrid = new ContextMenuItem(string.Format("<DIV onclick=JavaScript:gMapHybrid();>{0}</DIV>", GetLocalResourceObject("contextMenuViewHybridText.Text")));

            //contextMenuView.MenuItems.Add(contextMenuViewNormal);
            //contextMenuView.MenuItems.Add(contextMenuViewPhysical);
            //contextMenuView.MenuItems.Add(contextMenuViewSatellite);
            //contextMenuView.MenuItems.Add(contextMenuViewHybrid);

            //menuOnMap.MenuItems.Add(contextMenuView);
            //Map1.ContextMenu = menuOnMap; 
            #endregion

            ContextMenu menuOnMap = new ContextMenu("area", 180);
            ContextMenuItem redirectItem = new ContextMenuItem("<a href='http://www.thinkgeo.com' target='_blank'>ThinkGeo<a>");
            ContextMenuItem InfomationItem = new ContextMenuItem("<div onclick='popupInfomation();'>Infomation(Client Event)</div>");
            ContextMenuItem subItem = new ContextMenuItem();
            subItem.InnerHtml = "<Div>Test</Div>";

            ContextMenuItem contextMenuViewHybrid = new ContextMenuItem("<div onclick='gMapHybrid();'>Hybrid</div>");
            // or register the click event handler on the MenuItem like the way below
            //contextMenuViewHybrid.OnClientClick = "gMapHybrid";


            // Add the sub menu
            redirectItem.MenuItems.Add(subItem);

            // Add level 1 menu
            menuOnMap.MenuItems.Add(redirectItem);
            menuOnMap.MenuItems.Add(InfomationItem);
            menuOnMap.MenuItems.Add(contextMenuViewHybrid);

            // add the main context menu
            Map1.ContextMenu = menuOnMap;
        }

        /// <summary>
        /// Creates the base static layer from google.
        /// </summary>
        private void CreateBaseStaticLayerFromGoogle()
        {
            GoogleOverlay google = new GoogleOverlay("Google Map");
            google.JavaScriptLibraryUri = new Uri(ConfigurationManager.AppSettings["GoogleUri"]);
            google.GoogleMapType = GoogleMapType.Normal;
            this.Map1.CustomOverlays.Add(google);
        }

    }
}
